@@ -41,8 +41,6 @@
 
 #define KSERVICE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KSERVICE_NO_DEPRECATED) && !defined(KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KSERVICE_DEPRECATED
-#  define KSERVICE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KSERVICE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KSERVICE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
